| Trade_data_small | R Documentation |
The dataset contains bilateral trade and its economic determinants for 26 European Union countries over the period 1995–2015. Each observation represents a country pair, resulting in 325 unique trading pairs.
The countries included are: Austria, Belgium, Bulgaria, Cyprus, Czechia, Denmark, Estonia, Finland, France, Germany, Greece, Hungary, Ireland, Italy, Latvia, Lithuania, Luxembourg, the Netherlands, Poland, Portugal, Romania, Slovakia, Slovenia, Spain, Sweden, and the United Kingdom.
The dataset was used in: Beck (2020), What drives international trade? Robust analysis for the European Union, Journal of International Studies, 13(3), 68–84.
data(Trade_data_small)
A data frame with 325 rows and 11 variables:
Natural logarithm of bilateral trade between two countries.
Border dummy (1 if countries share a common border; 0 otherwise).
Natural logarithm of the shortest distance between capital cities.
Common language dummy (1 if countries share at least one official language; 0 otherwise).
Natural logarithm of the product of real GDPs of the two countries.
Absolute difference in human capital indicators.
Absolute difference in the standard deviation of inflation rates.
Absolute difference in arable land.
Absolute difference in arable land per worker.
Absolute difference in total land area.
Absolute difference in land area per capita.
Harvard Dataverse. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.7910/DVN/JMMOEA")}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.