coef_to_full: Extracting coefficients from g_regression and fast_ols...

View source: R/coef_to_full.R

coef_to_fullR Documentation

Extracting coefficients from g_regression and fast_ols function

Description

The function extracts coefficients or standard errors from the results of g_regression and fast_ols function

Usage

coef_to_full(model_coefs, model_row)

Arguments

model_coefs

a vector with estimated coefficients or standard errors

model_row

inclusion vector - row of a model space matrix

Value

A vector of coefficients coefficients or standard errors from the results of g_regression and fast_ols function


rmsBMA documentation built on March 14, 2026, 5:06 p.m.