fast_ols_const: OLS calculation with additional objects for model with just a...

View source: R/fast_ols_const.R

fast_ols_constR Documentation

OLS calculation with additional objects for model with just a constant.

Description

OLS calculation with additional objects for model with just a constant.

Usage

fast_ols_const(y)

Arguments

y

A vector with the dependent variable.

Value

A list with OLS objects: Coefficients, Standard errors, Marginal likelihood, R^2, Degrees of freedom, Determinant of the regressors matrix.

Examples


x1<-rnorm(10, mean = 0, sd = 1)
x2<-rnorm(10, mean = 0, sd = 2)
e<-rnorm(10, mean = 0, sd = 0.5)
y<-2+x1+2*x2+e
x<-cbind(x1,x2)
fast_ols_const(y)


rmsBMA documentation built on March 14, 2026, 5:06 p.m.