model_matrix: Matrix reflecting model space

View source: R/model_matrix.R

model_matrixR Documentation

Matrix reflecting model space

Description

The function creates a matrix with ones indicating inclusion and zeros indicating inclusion of a regressor in a model

Usage

model_matrix(K, M)

Arguments

K

total number of regressors

M

maximum number of regressor in a model

Value

A matrix with ones indicating inclusion and zeros indicating inclusion of a regressor in a model


rmsBMA documentation built on March 14, 2026, 5:06 p.m.