| model_pmp | R Documentation |
This function draws four graphs of prior and posterior model probabilities for the best individual models:
a) The results with binomial model prior (based on PMP - posterior model probability)
b) The results with binomial-beta model prior (based on PMP - posterior model probability)
Models on the graph are ordered according to their posterior model probability.
bma_list |
bma_list object (the result of the bma function) |
top |
The number of the best model to be placed on the graphs |
A list with three graphs with prior and posterior model probabilities for individual models:
The results with binomial model prior (based on PMP - posterior model probability)
The results with binomial-beta model prior (based on PMP - posterior model probability)
On graph combining the aforementioned graphs
data("Trade_data", package = "rmsBMA")
data <- Trade_data[,1:10]
modelSpace <- model_space(data, M = 9, g = "UIP")
bma_list <- bma(modelSpace)
model_pmps <- model_pmp(bma_list, top = 100)
model_pmps[[1]]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.