model_sizes: Graphs of the prior and posterior model probabilities of the...

View source: R/model_sizes.R

model_sizesR Documentation

Graphs of the prior and posterior model probabilities of the model sizes

Description

This function draws four graphs of prior and posterior model probabilities:
a) The results with binomial model prior (based on PMP - posterior model probability)
b) The results with binomial-beta model prior (based on PMP - posterior model probability)

Arguments

bma_list

bma_list object (the result of the bma function)

Value

A list with three graphs with prior and posterior model probabilities for model sizes:

  1. The results with binomial model prior (based on PMP - posterior model probability)

  2. The results with binomial-beta model prior (based on PMP - posterior model probability)

  3. One graph combining all the aforementioned graphs

Examples


data("Trade_data", package = "rmsBMA")
data <- Trade_data[,1:10]
modelSpace <- model_space(data, M = 9, g = "UIP")
bma_list <- bma(modelSpace)
sizes <- model_sizes(bma_list)
sizes[[1]]



rmsBMA documentation built on March 14, 2026, 5:06 p.m.