posterior_dens: Graphs of the posterior densities of the coefficients

View source: R/posterior_dens.R

posterior_densR Documentation

Graphs of the posterior densities of the coefficients

Description

This function draws graphs of the posterior densities of all the coefficients of interest.

Arguments

bma_list

bma object (the result of the bma function)

prior

Parameter indicating which model prior should be used for calculations:

  1. "binomial" - using binomial model prior (default option)

  2. "beta" - using binomial-beta model prior

Value

A list with the graphs of the posterior densities of coefficients for all the considered regressors.

Examples


data <- Trade_data[,1:10]
modelSpace <- model_space(data, M = 9, g = "UIP")
bma_list <- bma(modelSpace)
distPlots <- posterior_dens(bma_list, prior = "binomial")
distPlots[[1]]
distPlots[[2]]


rmsBMA documentation built on March 14, 2026, 5:06 p.m.