subset_design: Regressors choice based on the inclusion vector

View source: R/subset_design.R

subset_designR Documentation

Regressors choice based on the inclusion vector

Description

The function creates a matrix with regressors that should be included in a specific model based on inclusion vector

Usage

subset_design(x, model_row)

Arguments

x

matrix with regressors

model_row

inclusion vector - row of a model space matrix

Value

A matrix with regressors to be used in a specific model


rmsBMA documentation built on March 14, 2026, 5:06 p.m.