| bma | R Documentation |
This function calculates bma and related objects for the modelSpace object obtained using model_space function.
bma(
modelSpace,
EMS = NULL,
dilution = 0,
dil.Par = 0.5,
Narrative = 0,
p = NULL,
Nar_vec = NULL,
round = 6
)
modelSpace |
Model space object (the result of the model_space function) |
EMS |
Expected model size for model binomial and binomial-beta model prior. |
dilution |
Binary parameter: 0 - NO application of a dilution prior; 1 - application of a dilution prior (George 2010). |
dil.Par |
Parameter associated with dilution prior - the exponent of the determinant (George 2010). Used only if parameter dilution=1. |
Narrative |
Binary parameter: 0 - NO application of a Narrative dilution prior; 1 - application of a Narrative dilution prior. |
p |
Parameter or vector that indicates by how much we cut probability of a model with substitutes. |
Nar_vec |
Vector with information on narrative dilution prior where: 0 - the variable has no substitutes; numbers different than 0 denote consecutive groups of variables considered to be substitutes. |
round |
Parameter indicating to which place the function should round up the results in final tables. |
A list with Posterior objects:
pmp_uniform_table - table with results with PMP under binomial model prior
pmp_random_table - table with results with PMP under binomial-beta model prior
eba_object - table with results of Extreme Bounds Analysis
pms_table - table with prior and posterior model sizes
x_names - vector with names of the regressors - to be used by the functions
K - total number of regressors
MS - size of the mode space
EMS - expected model size for binomial and binomial-beta model prior specified by the user (default EMS=K/2)
dilution - parameter indicating use of dilution
for_jointness - table for jointness function
for_best_models - table for best_models function
for_model_pmp - table for model_pmp function
for_model_sizes - table for model_sizes function
alphas - vector with the values of the constant
betas_nonzero - matrix with coefficients on regressors
data("Trade_data", package = "rmsBMA")
data <- Trade_data
modelSpace <- model_space(data, M = 6)
bma_list <- bma(modelSpace)
bma_list[[1]]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.