| coef_to_full | R Documentation |
The function extracts coefficients or standard errors from the results of g_regression and fast_ols function
coef_to_full(model_coefs, model_row)
model_coefs |
a vector with estimated coefficients or standard errors |
model_row |
inclusion vector - row of a model space matrix |
A vector of coefficients coefficients or standard errors from the results of g_regression and fast_ols function
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.