| eba | R Documentation |
Computes Extreme Bounds Analysis (EBA) summaries for the intercept and each
regressor across a model space. For each coefficient, the function reports:
the minimum coefficient ("Low"), maximum coefficient ("High"), the mean
coefficient ("Mean_coef"), and corresponding "extreme bounds" defined as
\mathrm{Low} - 2\cdot \mathrm{SE} and \mathrm{High} + 2\cdot \mathrm{SE},
where \mathrm{SE}=\sqrt{\mathrm{VAR}} is the standard error associated
with the coefficient estimate in the model attaining the minimum/maximum.
eba(betas, VAR, Reg_ID, var_tol = 0)
betas |
Numeric matrix of dimension |
VAR |
Numeric matrix of dimension |
Reg_ID |
Numeric or integer matrix of dimension |
var_tol |
Nonnegative numeric scalar used as a tolerance when checking
variance positivity. Entries with |
The intercept (constant) is assumed to be included in all models. Each
regressor is summarized only over models in which it is included, as indicated
by the model-inclusion matrix Reg_ID.
A numeric matrix of dimension (K+1) x 5 with columns:
\min(\beta) - 2\cdot \mathrm{SE} evaluated at the model
where \beta is minimal.
Minimum coefficient value across relevant models.
Mean coefficient across relevant models (intercept: all models; regressor: included models only).
Maximum coefficient value across relevant models.
\max(\beta) + 2\cdot \mathrm{SE} evaluated at the model
where \beta is maximal.
Rows correspond to the intercept (row 1) and regressors (rows 2..K+1).
If a regressor is never included (no 1s in its column of Reg_ID), its row
will contain NA.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.