| model_matrix | R Documentation |
The function creates a matrix with ones indicating inclusion and zeros indicating inclusion of a regressor in a model
model_matrix(K, M)
K |
total number of regressors |
M |
maximum number of regressor in a model |
A matrix with ones indicating inclusion and zeros indicating inclusion of a regressor in a model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.