| model_sizes | R Documentation |
This function draws four graphs of prior and posterior model probabilities:
a) The results with binomial model prior (based on PMP - posterior model probability)
b) The results with binomial-beta model prior (based on PMP - posterior model probability)
bma_list |
bma_list object (the result of the bma function) |
A list with three graphs with prior and posterior model probabilities for model sizes:
The results with binomial model prior (based on PMP - posterior model probability)
The results with binomial-beta model prior (based on PMP - posterior model probability)
One graph combining all the aforementioned graphs
data("Trade_data", package = "rmsBMA")
data <- Trade_data[,1:10]
modelSpace <- model_space(data, M = 9, g = "UIP")
bma_list <- bma(modelSpace)
sizes <- model_sizes(bma_list)
sizes[[1]]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.