View source: R/posterior_dens.R
| posterior_dens | R Documentation |
This function draws graphs of the posterior densities of all the coefficients of interest.
bma_list |
bma object (the result of the bma function) |
prior |
Parameter indicating which model prior should be used for calculations:
|
A list with the graphs of the posterior densities of coefficients for all the considered regressors.
data <- Trade_data[,1:10]
modelSpace <- model_space(data, M = 9, g = "UIP")
bma_list <- bma(modelSpace)
distPlots <- posterior_dens(bma_list, prior = "binomial")
distPlots[[1]]
distPlots[[2]]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.