View source: R/subset_design.R
| subset_design | R Documentation |
The function creates a matrix with regressors that should be included in a specific model based on inclusion vector
subset_design(x, model_row)
x |
matrix with regressors |
model_row |
inclusion vector - row of a model space matrix |
A matrix with regressors to be used in a specific model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.